# from . import pyrk
# from pkg_resources import get_distribution
# from pyrk.pyrk import RK4
from .pyrk import RK4

__version__ = '0.7.0'
__license__ = 'MIT'
__copyright__ = 'copyright (c) 2016 Kevin J. Walchko'
__author__ = 'Kevin J. Walchko'
